pub enum RoomKeyWithheldContent {
MegolmV1AesSha2(MegolmV1AesSha2WithheldContent),
Unknown(UnknownRoomKeyWithHeld),
}Expand description
The m.room_key.withheld event content.
This is an enum over the different room key algorithms we support.
Devices that purposely do not send megolm keys to a device may instead send an m.room_key.withheld event as a to-device message to the device to indicate that it should not expect to receive keys for the message.
Variants
MegolmV1AesSha2(MegolmV1AesSha2WithheldContent)
The m.megolm.v1.aes-sha2 variant of the m.room_key.withheld content.
Unknown(UnknownRoomKeyWithHeld)
An unknown and unsupported variant of the m.room_key.withheld content.
Implementations
Sourceimpl RoomKeyWithheldContent
impl RoomKeyWithheldContent
Sourcepub fn new(
algorithm: EventEncryptionAlgorithm,
code: WithheldCode,
room_id: OwnedRoomId,
session_id: String,
sender_key: Curve25519PublicKey,
from_device: OwnedDeviceId,
) -> Self
pub fn new( algorithm: EventEncryptionAlgorithm, code: WithheldCode, room_id: OwnedRoomId, session_id: String, sender_key: Curve25519PublicKey, from_device: OwnedDeviceId, ) -> Self
Creates a withheld content from the given info
Panics
The method will panic if a unsupported algorithm is given. The only
supported algorithm as of now is m.megolm.v1.aes-sha2.
Sourcepub fn withheld_code(&self) -> WithheldCode
pub fn withheld_code(&self) -> WithheldCode
Get the withheld code of this event.
Sourcepub fn algorithm(&self) -> EventEncryptionAlgorithm
pub fn algorithm(&self) -> EventEncryptionAlgorithm
Get the algorithm of the room key withheld.
Sourcepub fn megolm_session_id(&self) -> Option<&str>
pub fn megolm_session_id(&self) -> Option<&str>
Get the megolm session ID of the withheld session, if it is in fact a megolm session.